docsbuilder

package
v0.28.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildCollectionReadme

func BuildCollectionReadme(ctx context.Context, col *ingitdb.CollectionDef, def *ingitdb.Definition,
	viewRenderer func(ctx context.Context, col *ingitdb.CollectionDef, view *ingitdb.ViewDef) (string, error)) (string, error)

BuildCollectionReadme generates the content of README.md for a collection

func BuildViewHeader added in v0.28.0

func BuildViewHeader(view *ingitdb.ViewDef) string

BuildViewHeader generates a human-readable header string based on ViewDef parameters.

func FindCollectionByDir added in v0.27.0

func FindCollectionByDir(collections map[string]*ingitdb.CollectionDef, dir string) *ingitdb.CollectionDef

FindCollectionByDir recursively searches for a collection by its directory path

func FindCollectionsForConflictingFiles added in v0.27.0

func FindCollectionsForConflictingFiles(def *ingitdb.Definition, wd string, conflictedFiles []string, resolveItems map[string]bool) (collectionsToUpdate []*ingitdb.CollectionDef, readmesToUpdate []string, unresolved []string)

FindCollectionsForConflictingFiles takes a list of conflicted files and a map of allowed resolutions. It returns a list of matched collections and a list of unresolved file paths.

func ProcessCollection added in v0.27.0

func ProcessCollection(ctx context.Context, def *ingitdb.Definition, col *ingitdb.CollectionDef, dbPath string, recordsReader ingitdb.RecordsReader) (bool, error)

func ResolveCollections

func ResolveCollections(collections map[string]*ingitdb.CollectionDef, pattern string) []*ingitdb.CollectionDef

ResolveCollections returns a list of collection definitions that match the dot-separated path or glob pattern.

func UpdateDocs

func UpdateDocs(ctx context.Context, def *ingitdb.Definition, collectionGlob string, dbPath string, recordsReader ingitdb.RecordsReader) (*ingitdb.MaterializeResult, error)

UpdateDocs resolves collections by dot-separated glob pattern and updates their README files

Types

type ViewRenderer added in v0.28.0

type ViewRenderer func(ctx context.Context, col *ingitdb.CollectionDef, view *ingitdb.ViewDef) (string, error)

Jump to