Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EventHandler ¶
type EventHandler func(RecordEvent)
EventHandler is called when a record changes.
type EventType ¶
type EventType string
EventType describes what kind of change occurred to a record file.
type FieldChange ¶
FieldChange captures a single field-level change within a record.
type RecordEvent ¶
type RecordEvent struct {
Type EventType
Path string
Changes []FieldChange
}
RecordEvent represents a change to a single record file.
Click to show internal directories.
Click to hide internal directories.